<?php

// If any errors occur while searching for a comic file, the error messages will be pushed into here.
$comic_pathfinding_errors = array();

// If ComicPress Manager is installed, use the date format defined there. If not, default to
// Y-m-d.. It's best to use CPM's date definition for improved operability between theme and plugin.

if (defined("CPM_DATE_FORMAT")) {
	define("CP_DATE_FORMAT", CPM_DATE_FORMAT);
} else {
	define("CP_DATE_FORMAT", "Y-m-d");
}

// If you want to run multiple comics on a single day, define your additional filters here.
// Example: you want to run an additional comic with the filename 2008-01-01-a-my-new-years-comic.jpg.
// Define an additional filter in the list below:
//
// $comic_filename_filters['secondary'] = "{date}-a*.*";
//
// Then show the second comic on your page by calling the_comic with your filter name (PHP tags munged
// to maintain valid file syntax):
//
// < ?php the_comic('secondary'); ? >
//
// Note that it's quite possible to slurp up the wrong file if your expressions are too broad.

$comic_filename_filters = array();
$comic_filename_filters['default'] = "{date}*.*";

if (!function_exists('comicpress_display_comic_area')) {
	function comicpress_display_comic_area() {
		global $post, $comicpress_options; ?>
		<div id="comic-wrap">
			<div id="comic-head"><?php get_sidebar('over'); ?></div>
			<div class="clear"></div>
			<?php get_sidebar('comicleft'); ?>
			<div id="comic">
				<?php echo comicpress_display_comic(); ?>
			</div>
			<?php get_sidebar('comicright'); ?>
			<div class="clear"></div>
			<div id="comic-foot"><?php get_sidebar('under'); ?></div>
		</div>
	<?php }	
}

function comicpress_display_comic_swf($post, $comic) {
	if (comicpress_this_is_multsite()) {
		$url_to_use = get_option('fileupload_url');
	} else {
		$url_to_use = get_bloginfo('wpurl');
	}
	$file_url = $url_to_use .'/' . comicpress_clean_filename($comic);
	$height = get_post_meta( $post->ID, "fheight", true );
	$width = get_post_meta( $post->ID, "fwidth", true );
	if (empty($height)) $height = '300';
	if (empty($width)) $width = '100%';
	$output = "<object id=\"myId\" classid=\"clsid:D27CDB6E-AE6D-11cf-96B8-444553540000\" width=\"{$width}\" height=\"{$height}\">\r\n";
	$output .= "	<param name=\"movie\" value=\"".get_comic_url()."\" />\r\n";
	$output .= "<!--[if !IE]>--><object type=\"application/x-shockwave-flash\" data=\"".$file_url."\" width=\"{$width}\" height=\"{$height}\"><!--<![endif]-->\r\n";
	$output .= "		<div>\r\n";
	$output .= "			<h1>Get Flash!</h1>\r\n";
	$output .= "				<p><a href=\"http://www.adobe.com/go/getflashplayer\"><img src=\"http://www.adobe.com/images/shared/download_buttons/get_flash_player.gif\" alt=\"Get Adobe Flash player\" /></a></p>\r\n";
	$output .= "		</div>\r\n";
	$output .= "<!--[if !IE]>--></object><!--<![endif]--></object>\r\n";
	return apply_filters('comicpress_display_comic_swf',$output);
}

// This function will let authors who want to use comicpress as a way to output their books/text in a comic area as a page.
function comicpress_display_comic_text($comic) {
	global $comicpress_stylesheet_directory;

	$path_to_use = get_option('upload_path');
	$cwd = $comicpress_stylesheet_directory;
	if ($cwd !== false) {
		// Strip the wp-admin part and just get to the root.
		$root_path = preg_replace('#[\\/]wp-(admin|content).*#', '', $cwd);
	}
	$path_to_file = $root_path .'/' .$path_to_use. '/' .$comic;

	if (file_exists($path_to_file)) {
		$output = file_get_contents($path_to_file);
	}
	return apply_filters('comicpress_display_comic_text',$output);
}


// Do the thumbnail display functions here.
function comicpress_display_comic_thumbnail($type, $post, $use_post_image = false) {
	global $post, $rss_comic_folder, $archive_comic_folder, $mini_comic_folder, $comic_folder, 
	$comicpress_stylesheet_directory_uri, $comicpress_stylesheet_directory,
	$comicpress_stylesheet_directory_uri, $comicpress_template_directory_uri;
	$post_to_use = !is_null($override_post) ? $override_post : $post;
	
	// use_post_image if its set to true
	if ($use_post_image && function_exists('has_post_thumbnail')) {
		if ( has_post_thumbnail($post_to_use->ID) ) {
			$comic_image = get_the_post_thumbnail($post_to_use->ID,'full');
			$comic_image = preg_replace('#title="([^*]*)"#', 'title="'.$title_to_use.'"', $comic_image);
		} 
	}
	
	if (empty($comic_image)) {
		// Use the first comic found as the thumbnail to whats there.
		$comics = get_comic_path('comic', false, $post_to_use);
		$comic = reset($comics);
		
		// Split the comic to find out if we need to do something special with it.
		$comicsplit = explode(".", basename($comic));
		
		// Use a generic graphic for .htm's and .swf's as the thumbnail, which is replaceable in childtheme
		switch (strtolower($comicsplit[1])) {
			case 'swf':
				if (file_exists($comicpress_stylesheet_directory.'/images/mediafile.png')) {
					$directory_to_use = $comicpress_stylesheet_directory_uri;
				} else {
					$directory_to_use = $comicpress_template_directory_uri;
				}
				$comic_image = "<img src=\"{$directory_to_use}/images/mediafile.png\" alt=\"".$post_to_use->post_title."\" />";
				break;
			case 'txt':
			case 'inc':
			case 'php':
			case 'htm':
				if (file_exists($comicpress_stylesheet_directory.'/images/specialfile.png')) {
					$directory_to_use = $comicpress_stylesheet_directory_uri;
				} else {
					$directory_to_use = $comicpress_template_directory_uri;
				}
				$comic_image = "<img src=\"{$directory_to_use}/images/specialfile.png\" alt=\"".$post_to_use->post_title."\" />";
				break;
			default:
				break;
		}
	}
	
	if (empty($comic_image)) {
		if (comicpress_this_is_multsite()) {
			$url_to_use = get_option('fileupload_url');
		} else {
			$url_to_use = get_bloginfo('wpurl');
		}
		
		switch ($type) {
			case "rss": $folder_to_use = $rss_comic_folder; break;
			case "archive": $folder_to_use = $archive_comic_folder; break;
			case "mini": $folder_to_use = $mini_comic_folder; break;
			case "comic": default: $folder_to_use = $comic_folder; break;
		}
		
		$cwd = $comicpress_stylesheet_directory;
		if ($cwd !== false) {
			// Strip the wp-admin part and just get to the root.
			$root_path = preg_replace('#[\\/]wp-(admin|content).*#', '', $cwd);
		}
		
		$path_to_file = $root_path .'/' .$folder_to_use. '/' .basename($comic);
		
		if (comicpress_this_is_multsite()) {
			if (($wpmu_path = get_option('upload_path')) !== false) {
				$path_to_use = $wpmu_path . '/' . $folder_to_use;
				$path_to_file = $root_path .'/' .$path_to_use. '/' .basename($comic);
			}
		}
		
		if (!file_exists($path_to_file)) {
			$folder_to_use = $comic_folder;
		}
		
		$comic_url = $url_to_use .'/' . $folder_to_use .'/'. comicpress_clean_filename(basename($comic));
	}
	if (!empty($comic_image)) {
		$output = $comic_image;
	} else {
		$output = '<img src="'.$comic_url.'" alt="'.get_the_title($post_to_use).'" title="'.get_the_title($post_to_use).'" />';
	}
	return apply_filters('comicpress_display_comic_thumbnail',$output);
}

// TODO: Add the hovertext - rascal code and click to next INSIDE this.
function comicpress_display_comic_image($post, $comic) {
	global $comicpress_options;
	if (comicpress_this_is_multsite()) {
		$url_to_use = get_option('fileupload_url');
	} else {
		$url_to_use = get_bloginfo('wpurl');
	}
	$file_url = $url_to_use .'/' . comicpress_clean_filename($comic);
	if ($comicpress_options['rascal_says']) {
		$alt_text = get_the_title($post);
	} else {
		$alt_text = the_hovertext($post);
	}
	$output = '<img src="'.$file_url.'" alt="'.$alt_text.'" title="'.$alt_text.'" />';
	return apply_filters('comicpress_display_comic_image',$output);
}

// jquery code image swap by @brianarn
function comicpress_display_comic() {
	global $post;
	$comics = get_comic_path('comic', false, $post);
	if (is_array($comics)) {
		$count = 1;
		$outputlist = '';
		foreach ($comics as $comic) {
			$comicsplit = explode(".", $comic); 
			switch (strtolower($comicsplit[1])) {
				case 'swf':
					$output .= '<div id="comic-'.$count.'" class="comicpane">';
					$output .= comicpress_display_comic_swf($post, $comic);
					$output .= "</div>\r\n";
					$outputlist .= "<button id=\"show-".$count."\" type=\"button\">".$count."</button>\r\n";
					$count += 1;
					break;
				case 'txt':
				case 'inc':
				case 'htm':
					$output .= '<div id="comic-'.$count.'" class="comicpane">';
					$output .= comicpress_display_comic_text($comic);
					$output .= "</div>\r\n";
					$outputlist .= "<button id=\"show-".$count."\" type=\"button\">".$count."</button>\r\n";
					$count += 1;
					break;
				case 'png':
				case 'gif':
				case 'jpg':
				default:
					$output .= '<div id="comic-'.$count.'" class="comicpane">';
					$output .= comicpress_display_comic_image($post, $comic);
					$output .= "</div>\r\n";
					$outputlist .= "<button id=\"show-".$count."\" type=\"button\">".$count."</button>\r\n";
					$count += 1;
			}
		}
		if ($count > 2 && $comicpress_options['enable_multicomic_jquery']) {
			// Add the script stuff before the rest here.
			$output = $outputscript . $output;
		}
	}
	return $output;
}



if (!function_exists('comicpress_comic_clicks_next')) {
	function comicpress_comic_clicks_next($output) {
		global $post, $wp_query, $comicpress_options;
		if (is_search() || is_archive() || is_feed()) return $output;
		$hovertext = the_hovertext($post);
		$next_comic = get_next_comic_permalink();
		$class = '';
		if ($comicpress_options['rascal_says']) {
			$the_title = get_the_title($post);
			$class='class="tt"';
		} else {
			$the_title = the_hovertext($post);
		}
		$output = "<a {$class} href=\"{$next_comic}\" title=\"{$the_title}\">{$output}</a>\r\n";
		return $output;
	}
}

function comicpress_rascal_says($output) {
	global $post, $wp_query, $comicpress_options;
	if (is_search() || is_archive() || is_feed()) return $output;
	$hovertext = get_post_meta( $post->ID, "hovertext", true );
	$href_to_use = "#";
	if (!empty($hovertext)) {
		$output = preg_replace('#title="([^*]*)"#', '', $output);
		$output = "<span class=\"tooltip\"><span class=\"top\">&nbsp;</span><span class=\"middle\">{$hovertext}</span><span class=\"bottom\">&nbsp;</span></span>{$output}\r\n";
	}
	if ($comicpress_options['comic_clicks_next']) {
		$href_to_use = get_next_comic_permalink();
		$output = "<a href=\"{$href_to_use}\" class=\"tt\" title=\"".$post->post_title."\">{$output}</a>";
	} else {
		$output = "<a class=\"tt\" href=\"{$href_to_use}\" title=\"".$post->post_title."\">{$output}</a>";
	}
	return apply_filters('comicpress_rascal_says',$output);
}

global $comicpress_options;

if ($comicpress_options['rascal_says']) {
	add_filter('comicpress_display_comic_image', 'comicpress_rascal_says');
}

if ($comicpress_options['comic_clicks_next'] && !$comicpress_options['rascal_says']) { 
	add_filter('comicpress_display_comic_image', 'comicpress_comic_clicks_next'); 
}

/**
* Find a comic file in the filesystem.
* @param string $folder The folder name to search.
* @param string $override_post A WP Post object to use in place of global $post.
* @param string $filter The $comic_filename_filters to use.
* @return string The relative path to the comic file, or false if not found.
*/

function get_comic_path($folder = 'comic', $override_post = null, $filter = 'default') {
	global $post, $comic_filename_filters, $comic_folder, $comicpress_stylesheet_directory, $archive_comic_folder, $rss_comic_folder, $mini_comic_folder, $comic_pathfinding_errors;
	
	if (isset($comic_filename_filters[$filter])) {
		$filter_to_use = $comic_filename_filters[$filter];
	} else {
		$filter_to_use = '{date}*.*';
	}
	
	switch ($folder) {
		case "rss": $folder_to_use = $rss_comic_folder; break;
		case "archive": $folder_to_use = $archive_comic_folder; break;
		case "mini": $folder_to_use = $mini_comic_folder; break;
		case "comic": default: $folder_to_use = $comic_folder; break;
	}
	$orig_folder_to_use = $folder_to_use;
	if (comicpress_this_is_multsite()) {
		if (($wpmu_path = get_option('upload_path')) !== false) {
			$folder_to_use = $wpmu_path . '/' . $folder_to_use;
		}
	}
	
	$post_to_use = (is_object($override_post)) ? $override_post : $post;
	$post_date = mysql2date(CP_DATE_FORMAT, $post_to_use->post_date);
	
	$filter_with_date = str_replace('{date}', $post_date, $filter_to_use);
	
	$cwd = $comicpress_stylesheet_directory;
	if ($cwd !== false) {
		// Strip the wp-admin part and just get to the root.
		$root_path = preg_replace('#[\\/]wp-(admin|content).*#', '', $cwd);
	}
	
	$results = array();
	/* have to use root_path to get subdirectory installation directories */

	if (count($results = glob("${root_path}/${folder_to_use}/${filter_with_date}")) > 0) {
		$newresults = array();
		foreach ($results as $result) {
			// Strip the root path
			$newresults[] = str_replace("${root_path}/${folder_to_use}/", "{$orig_folder_to_use}/", $result);
		}
		return $newresults;
	}
	
	$comic_pathfinding_errors[] = sprintf(__("Unable to find the file in the <strong>%s</strong> folder that matched the pattern <strong>%s</strong>. Check your WordPress and ComicPress settings.", 'comicpress'), $folder_to_use, $filter_with_date);
	return false;
}


/**
* Find a comic file in the filesystem and return an absolute URL to that file.
* @param string $folder The folder name to search.
* @param string $override_post A WP Post object to use in place of global $post.
* @param string $filter The $comic_filename_filters to use.
* @return string The absolute URL to the comic file, or false if not found.
*/
function get_comic_url($folder = 'comic', $override_post = null, $filter = 'default') {
	if (($results = get_comic_path($folder, $override_post, $filter)) !== false) {
		$newresults = array();
		foreach ($results as $result) {
			if (comicpress_this_is_multsite()) {
				$newresults[] = get_option('fileupload_url') .'/'. $result;
			} else {
				$newresults[] = get_bloginfo('wpurl') .'/'. $result;
			}
		}
		return $newresults;
	}
	return false;
}


?>